@@ -27,23 +27,17 @@ CMD ["pipenv run python /app/server.py"]
 SERVER = """
 import os
 from flask import Flask, request, jsonify
-from flask_cors import CORS
+from flask_cors import CORS, cross_origin
 from system import *
 
 app = Flask(__name__)
+CORS(app, support_credentials=True)
 app.config['CORS_HEADERS'] = 'Content-Type'
-CORS(app, resources={r"/*": {"origins": "*"}})
 
 system = System()
 
-@app.after_request
-def after_request(response):
-  response.headers.add('Access-Control-Allow-Origin', '*')
-  response.headers.add('Access-Control-Allow-Headers', 'Content-Type,Authorization')
-  response.headers.add('Access-Control-Allow-Methods', 'GET, PUT, POST, DELETE, OPTIONS')
-  return response
-
-@app.route("/predict", methods=['POST', 'OPTIONS', 'GET'])
+@app.route("/predict", methods=['POST', 'OPTIONS'])
+@cross_origin(supports_credentials=True)
 def predict():
     input_object = request.get_json()['input']
     return jsonify(output=system.output(input_object))
